﻿using System.Text;
using System.Web.Mvc;

namespace Utils
{
	public static class GoogleChart
	{
		#region ChartTypes
		public static string LineChart = "lc";
		public static string SparkLine = "ls";
		public static string AxisLineChart = "lxy";
		public static string HorizontalBarChart = "bhs";
		public static string HorizontalBarChartGrouped = "bhg";
		public static string VerticalBarChart = "bvs";
		public static string VerticalBarChartGrouped = "bvg";
		public static string PieChart = "p";
		public static string ThreeDimensionPieChart = "p3";
		public static string ConcentricPieChart = "pc";
		public static string VennDiagram = "v";
		public static string ScatterPlot = "s";
		public static string Map = "t";
		#endregion

		#region MapDetails

		public static string RegionAfrica = "africa";
		public static string RegionAsia = "asia";
		public static string RegionEurope = "europe";
		public static string RegionMiddleEast = "middle_east";
		public static string RegionSouthAmerica = "south_america";
		public static string RegionUsa = "usa";
		public static string RegionWorld = "world";

		#endregion


		/// <summary>
		/// Draws the chart.
		/// </summary>
		/// <param name="helper">The helper.</param>
		/// <param name="chartType">Type of the chart.</param>
		/// <param name="chartData">The chart data.</param>
		/// <param name="chartSize">Size of the chart.</param>
		/// <param name="chartLabel">The chart label.</param>
		/// <returns></returns>
		public static string DrawChart(this HtmlHelper helper, string chartType, string chartData, string chartSize, string chartLabel)
		{
			StringBuilder chartHtml = new StringBuilder("<img src='http://chart.apis.google.com/chart?chs=");
			chartHtml.Append(chartSize);
			chartHtml.Append("&amp;chd=t:");
			chartHtml.Append(chartData);
			chartHtml.Append("&amp;cht=");
			chartHtml.Append(chartType);
			chartHtml.Append("&amp;chl=");
			chartHtml.Append(chartLabel);
			chartHtml.Append("' />");

			return chartHtml.ToString();
		}

		/// <summary>
		/// Draws the chart.
		/// </summary>
		/// <param name="helper">The helper.</param>
		/// <param name="chartType">Type of the chart.</param>
		/// <param name="chartData">The chart data.</param>
		/// <param name="chartSize">Size of the chart.</param>
		/// <param name="chartLabel">The chart label.</param>
		/// <returns></returns>
		public static string DrawChart(this HtmlHelper helper, string chartType, string[] chartData, string chartSize, string chartLabel)
		{
			string newChartData = string.Join(",", chartData);
			return DrawChart(helper, chartType, newChartData, chartSize, chartLabel);
		}

		/// <summary>
		/// Draws the map.
		/// </summary>
		/// <param name="helper">The helper.</param>
		/// <param name="chartData">The chart data.</param>
		/// <param name="chartSize">Size of the chart.</param>
		/// <param name="mapRegion">The map region.</param>
		/// <returns></returns>
		public static string DrawMap(this HtmlHelper helper, string chartData, string chartSize, string mapRegion)
		{
			StringBuilder chartHtml = new StringBuilder("<img src='http://chart.apis.google.com/chart?cht=");
			chartHtml.Append(Map);
			chartHtml.Append("&amp;chtm=");
			chartHtml.Append(mapRegion);
			chartHtml.Append("&amp;chd=t:");
			chartHtml.Append(chartData);
			chartHtml.Append("&amp;chs=");
			chartHtml.Append(chartSize);
			chartHtml.Append("' />");

			return chartHtml.ToString();
		}

		/// <summary>
		/// Draws the map.
		/// </summary>
		/// <param name="helper">The helper.</param>
		/// <param name="chartData">The chart data.</param>
		/// <param name="chartSize">Size of the chart.</param>
		/// <param name="mapRegion">The map region.</param>
		/// <returns></returns>
		public static string DrawMap(this HtmlHelper helper, string[] chartData, string chartSize, string mapRegion)
		{
			string newChartData = string.Join(",", chartData);
			return DrawMap(helper, newChartData, chartSize, mapRegion);
		}
	}
}

